Attributes of LatLon classes

PyGeodesy | 26.3.26 | class LatLon in module
|  | pygeodesy.ellipsoidal- | pygeodesy.spherical-
attribute | type | -Exact | -Karney | -Nvector | -Vincenty | -Nvector | -Trigonometry
alongTrackDistanceTo | method | - | - | - | - | A | A
antipode | method | C | C | C | C | D | C
attrs | method | G | G | G | G | G | F
bearingTo** | method | - | A | - | A | A | A
bearingTo2 | method | B | B | - | B | C | B
bounds** | method | D | D | D | D | D | C
boundsOf | method | D | D | D | D | D | C
chordTo | method | D | D | D | D | D | C
circin6 | method | D | D | D | D | D | C
circum3 | method | D | D | D | D | D | C
circum4_ | method | D | D | D | D | D | C
classname | Property* | G | G | G | G | G | F
classnaming | property | G | G | G | G | G | F
classof | method | G | G | G | G | G | F
clipid | property | D | D | D | D | D | C
compassAngle** | method | D | D | D | D | D | C
compassAngleTo | method | D | D | D | D | D | C
convergence** | property* | C | C | C | C | - | -
convertDatum** | method | C | C | C | C | - | -
convertRefFrame** | method | C | C | C | C | - | -
copy | method | G | G | G | G | G | F
cosineAndoyerLambertTo** | method | D | D | D | D | D | C
cosineForsytheAndoyerLambertTo** | method | D | D | D | D | D | C
cosineLawTo | method | D | D | D | D | D | C
crossingParallels | method | - | - | - | - | - | A
crossTrackDistanceTo | method | - | - | - | - | A | A
datum | property | C | C | C | C | C | B
deltaTo | method | - | - | A | - | - | -
destination | method | B | B | - | B | A | A
destination2 | method | B | B | - | B | - | -
destinationNed | method | - | - | A | - | - | -
destinationXyz | method | D | D | D | D | D | C
distanceTo | method | B | B | A | B | A | A
distanceTo2 | method | C | C | C | C | - | -
distanceTo3 | method | B | B | - | B | - | -
dup | method | G | G | G | G | G | F
Ecef | property* | F | F | A | A | F | E
elevation2 | method | C | C | C | C | - | -
ellipsoid | method | C | C | C | C | - | -
ellipsoidalLatLon | property* | C | C | C | C | D | C
ellipsoids | method | C | C | C | C | - | -
epoch | property | C | C | C | C | - | -
epsilon | property | - | - | - | A | - | -
equals** | method | D | D | A | D | D | C
equals3** | method | D | D | D | D | D | C
Equidistant | Property* | A | A | C | C | - | -
equirectangularTo | method | D | D | D | D | D | C
euclideanTo | method | D | D | D | D | D | C
finalBearingOn | method | B | B | - | B | - | -
finalBearingTo | method | B | B | - | B | C | B
flatLocalTo | method | D | D | D | D | D | C
flatPolarTo | method | D | D | D | D | D | C
gamma | property* | C | C | C | C | - | -
geodesic | Property* | A | A | - | - | - | -
geodesic | property* | - | - | - | B | - | -
geodesicx | Property* | A | - | - | - | - | -
geoidHeight2 | method | C | C | C | C | - | -
greatCircle | method | - | - | - | - | A | A
greatCircleTo | method | - | - | - | - | A | -
hartzell | method | D | D | D | D | D | C
haversineTo | method | D | D | D | D | D | C
height | Property | D | D | D | D | D | C
height4 | method | D | D | D | D | D | C
heightStr | method | D | D | D | D | D | C
hubenyTo | method | D | D | D | D | D | C
initialBearingTo | method | B | B | - | B | A | A
intermediateChordTo | method | - | - | - | - | A | -
intermediateTo | method | B | B | A | B | A | A
intersecant2 | method | B | B | - | B | C | B
intersection | method | - | - | - | - | A | A
intersection2 | method | - | - | - | - | A | -
intersection3 | method | C | C | C | C | - | -
intersections2 | method | C | C | - | C | - | A
isantipode** | method | D | D | D | D | D | C
isantipodeTo | method | D | D | D | D | D | C
isEllipsoidal | Property* | D | D | D | D | D | C
isenclosedBy | method | C | C | C | C | A | A
isEnclosedBy** | method | - | - | - | - | A | A
isequalTo | method | D | D | A | D | D | C
isequalTo3 | method | D | D | D | D | D | C
isnormal | Property* | D | D | D | D | D | C
isSpherical | Property* | D | D | D | D | D | C
iswithin | method | - | - | - | - | A | -
isWithin** | method | - | - | - | - | A | -
iteration | property* | C | C | C | C | G | F
iterations | property | - | - | - | A | - | -
lam | Property* | D | D | D | D | D | C
lat | Property | D | D | D | D | D | C
latlon | Property | D | D | D | D | D | C
latlon2 | method | D | D | D | D | D | C
latlon2round** | method | D | D | D | D | D | C
latlon_** | method | D | D | D | D | D | C
latlonheight | Property | D | D | D | D | D | C
lon | Property | D | D | D | D | D | C
maxLat | method | - | - | - | - | C | B
methodname | method | G | G | G | G | G | F
midpointTo | method | C | C | C | C | A | A
minLat | method | - | - | - | - | C | B
name | property | G | G | G | G | G | F
named | Property* | G | G | G | G | G | F
named2 | Property* | G | G | G | G | G | F
named3 | Property* | G | G | G | G | G | F
named4 | Property* | G | G | G | G | G | F
napieradius | property | - | - | - | - | C | B
nearestOn | method | C | C | C | C | A | A
nearestOn2** | method | - | - | - | - | A | A
nearestOn3 | method | - | - | - | - | A | A
nearestOn6 | method | D | D | D | D | D | C
nearestOn8 | method | B | B | - | B | - | -
normal | method | D | D | D | D | D | C
others | method | E | E | B | E | B | D
parse | method | C | C | C | C | C | B
phi | Property* | D | D | D | D | D | C
philam | Property* | D | D | D | D | D | C
philam2 | method | D | D | D | D | D | C
philamheight | Property* | D | D | D | D | D | C
plumbTo | method | B | B | - | B | - | -
points** | method | D | D | D | D | D | C
points2 | method | D | D | D | D | D | C
PointsIter | method | D | D | D | D | D | C
radii11 | method | D | D | D | D | D | C
reframe | property | C | C | C | C | - | -
rename | method | G | G | G | G | G | F
renamed | method | G | G | G | G | G | F
rhumbAzimuthTo | method | D | D | D | D | C | B
rhumbBearingTo** | method | - | - | - | - | C | B
rhumbDestination | method | D | D | D | D | C | B
rhumbDistanceTo | method | D | D | D | D | C | B
rhumbIntersecant2 | method | D | D | D | D | C | B
rhumbLine | method | D | D | D | D | D | C
rhumbMidpointTo | method | D | D | D | D | C | B
scale | Property* | C | C | C | C | - | -
sizeof | property* | G | G | G | G | G | F
sphericalLatLon | property* | D | D | D | D | C | B
thomasTo | method | D | D | D | D | D | C
to2ab** | method | D | D | D | D | D | C
to3llh** | method | D | D | D | D | D | C
to3xyz** | method | C | C | C | C | D | C
toAer | method | F | F | F | F | F | E
toCartesian | method | A | A | A | A | A | A
toCss | method | C | C | C | C | - | -
toDatum | method | C | C | C | C | - | -
toEcef | method | D | D | D | D | D | C
toEnu | method | F | F | F | F | F | E
toEtm | method | C | C | C | C | - | -
toLcc | method | C | C | C | C | - | -
toLocal | method | F | F | F | F | F | E
toLtp | method | F | F | F | F | F | E
toMgrs | method | C | C | C | C | - | -
toNed | method | F | F | F | F | F | E
toNormal | method | D | D | D | D | D | C
toNvector | method | D | D | A | D | A | B
toOsgr | method | C | C | C | C | - | -
toRefFrame | method | C | C | C | C | - | -
toRepr | method | E | E | E | E | E | D
toStr | method | D | D | D | D | D | C
toStr2** | method | G | G | G | G | G | F
toTransform | method | C | C | C | C | - | -
toUps | method | C | C | C | C | - | -
toUtm | method | C | C | C | C | - | -
toUtmUps | method | C | C | C | C | - | -
toVector | method | D | D | D | D | D | C
toVector3d | method | D | D | D | D | D | C
toWm | method | D | D | D | D | D | C
toXyz | method | F | F | F | F | F | E
triangle7 | method | - | - | - | - | - | A
triangulate | method | C | C | B | C | B | A
trilaterate | method | - | - | B | - | B | -
trilaterate5 | method | C | C | - | C | - | A
typename | property* | G | G | G | G | G | F
vincentysTo | method | D | D | D | D | D | C
xyz | property* | D | D | D | D | D | C
xyz3 | property* | D | D | D | D | D | C
xyzh | Property* | D | D | D | D | D | C
**) DEPRECATED | *) immutable | A: class attribute | B, C, ...: attribute of a super class